#!/usr/bin/bash

PACK_LIST=("git" "zsh")
# 脚本根地址
ROOT_URL="https://gitea.whlug.cn/xunmi/x/"
# 脚本安装默认路径
ROOT_INSTALL="/opt/xunmi"

###############################################################################
# 终端配色                                                                    #
###############################################################################

readonly COLOUR_RESET='\e[0m'
readonly aCOLOUR=(
	'\e[38;5;154m' 	# 0: 亮绿
	'\e[1m'        	# 1: 白
	'\e[90m'       	# 2: 灰
	'\e[91m'       	# 3: 红
	'\e[32m'		# 4: 绿
)
Show() {
    if (($1 == 0)); then
        echo -e "${aCOLOUR[2]}[$COLOUR_RESET${aCOLOUR[0]} 成功 $COLOUR_RESET${aCOLOUR[2]}]$COLOUR_RESET $2"
    elif (($1 == 1)); then
        echo -e "${aCOLOUR[2]}[$COLOUR_RESET${aCOLOUR[3]} 失败 $COLOUR_RESET${aCOLOUR[2]}]$COLOUR_RESET $2"
        exit 1
    elif (($1 == 2)); then
        echo -e "${aCOLOUR[2]}[$COLOUR_RESET${aCOLOUR[4]} 信息 $COLOUR_RESET${aCOLOUR[2]}]$COLOUR_RESET $2"
    fi
}
GreyStart() {
    echo -e "${aCOLOUR[2]}\c"
}
ColorReset() {
    echo -e "$COLOUR_RESET\c"
}

###############################################################################
# 函数                                                                        #
###############################################################################

# 更新包管理器
Update_PKG() {
    Show 2 "更新包管理器..."
	GreyStart
	if [ -x "$(command -v oma)" ]; then
		sudo oma refresh
    elif [ -x "$(command -v apt)" ]; then
        sudo apt-get update -qq
    elif [ -x "$(command -v yum)" ]; then
        sudo yum update
    fi
    ColorReset
    Show 0 "包管理器更新完毕"
}

# 安装依赖
Install_PKG() {
	Update_PKG
	for ((i = 0; i < ${#PACK_LIST[@]}; i++)); do
		pack=${PACK_LIST[i]}
		[ -x "$(command -v $pack)" ] && continue
		Show 2 "安装必要的依赖项: ${aCOLOUR[4]} $pack $COLOUR_RESET"
		GreyStart
		if [ -x "$(command -v oma)" ]; then
			sudo oma install -y $pack
		elif [ -x "$(command -v apt)" ]; then
			sudo apt -y install $pack
		elif [ -x "$(command -v yum)" ]; then
			sudo yum install -y $pack 
		elif [ -x "$(command -v pacman)" ]; then
			sudo pacman -Sy --needed $pack
    	else
       		Show 1 "未找到包管理器, 您需要手动安装: ${aCOLOUR[5]} $pack $COLOUR_RESET"
    	fi
		ColorReset
	done
	Show 0 "依赖安装完成"
}

Download_X(){
	Show 0 "开始下载配置言灵"
	GreyStart
	x_dir=$ROOT_INSTALL/x
	sudo rm -vrf $x_dir
	sudo git clone $ROOT_URL $x_dir || Show 1 "言灵拉去失败"
	mkdir -vp $HOME/.config/xunmi
	echo "言灵一路径=$ROOT_INSTALL" >> $HOME/.config/xunmi/信息
	ColorReset
}

#################################################################
# 主函数(main)													#
#################################################################

Install_PKG
Download_X
sudo chown -R $USER:$USER $ROOT_INSTALL
[ -f "安装.zsh" ] && zsh 安装.zsh || zsh $x_dir/安装.zsh
exec zsh
